<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 *
 */
function optionsframework_option_name() {

	// This gets the theme name from the stylesheet (lowercase and without spaces)
	$themename = get_option( 'stylesheet' );
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option('optionsframework');
	$optionsframework_settings['id'] = $themename;
	update_option('optionsframework', $optionsframework_settings);

	// echo $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 */

function optionsframework_options() {


	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}

	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}
	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/images/';

	$options = array();

$options[] = array(
		'name' => __('تنظیمات پایه', 'options_check'),
		'type' => 'heading');
$options[] = array(
		'name' => __('رمز فایل فشرده', 'options_check'),
		'desc' => __(' اگر فایلهای دانلودی رمز عبور دارند آنرا در این بخش وارد کنید', 'options_check'),
		'id' => 'reza-game-tab-id14521', //example_text
		'std' => 'www.ronakweb.com',
		'type' => 'text');
$options[] = array(
		'name' => __('شبکه اجتماعی', 'options_check'),
		'type' => 'heading');
$options[] = array(
		'name' => __('صفحه فیسبوک', 'options_check'),
		'desc' => __('آدرس صفحه فیسبوک سایت را در این محل وارد کنید.', 'options_check'),
		'id' => 'face-id1', //example_text
		'std' => 'http://facebook.com',
		'type' => 'text');
$options[] = array(
		'name' => __('صفحه گوگل پلاس', 'options_check'),
		'desc' => __('آدرس صفحه گوگل پلاس سایت را در این محل وارد کنید.', 'options_check'),
		'id' => 'google-id1', //example_text
		'std' => 'http://google.com',
		'type' => 'text');
$options[] = array(
		'name' => __('صفحه توئیتر', 'options_check'),
		'desc' => __('آدرس صفحه توئیتر سایت را در این محل وارد کنید.', 'options_check'),
		'id' => 'twitter-id1', //example_text
		'std' => 'http://twitter.com',
		'type' => 'text');
$options[] = array(
		'name' => __('صفحه لینکدین', 'options_check'),
		'desc' => __('آدرس صفحه لینکدین سایت را در این محل وارد کنید.', 'options_check'),
		'id' => 'linkedin-id1', //example_text
		'std' => 'http://linkedin.com',
		'type' => 'text');
$options[] = array(
		'name' => __('صفحه اینستاگرام', 'options_check'),
		'desc' => __('آدرس صفحه اینستاگرام سایت را در این محل وارد کنید.', 'options_check'),
		'id' => 'instagram-id1', //example_text
		'std' => 'http://instagram.com',
		'type' => 'text');
$options[] = array(
		'name' => __('تنظیمات تصاویر', 'options_check'),
		'type' => 'heading');
$options[] = array(
		'name' => __('تغییر لوگو', 'options_check'),
		'desc' => __('لوگو جدید در ابعاد 272 در 93 پیکسل را وارد نمایید .', 'options_check'),
		'id' => 'rezakianoosh_uploader',
		'type' => 'upload');
$options[] = array(
		'name' => __('تغییر آیکون', 'options_check'),
		'desc' => __('برای تغییر آیکون کنار عنوان سایت در مرورگر تصویری با ابعاد 24 در 24 پیکسل وارد نمایید.', 'options_check'),
		'id' => 'rezakianoosh_uploader_ronakweb214',
		'type' => 'upload');
$options[] = array(
		'name' => __('تنظیمات تبلیغات', 'options_check'),
		'type' => 'heading');
$options[] = array(
		'name' => __('تعداد تبلیغات بنری زیر هدر', 'options_check'),
		'desc' => __('تعداد تبلیغات بنری مورد نمایش در زیر هدر را وارد کنید. (عدد صفر قابل قبول نیست)', 'options_check'),
		'id' => 'reza-kianoosh-top-id1', //example_text
		'std' => '6',
		'type' => 'text');
$options[] = array(
		'name' => __('تعداد تبلیغات بنری ستون چپ', 'options_check'),
		'desc' => __('تعداد تبلیغات بنری مورد نمایش در ستون چپ را وارد کنید. (عدد صفر قابل قبول نیست)', 'options_check'),
		'id' => 'reza-kianoosh-left-b-id1', //example_text
		'std' => '4',
		'type' => 'text');
$options[] = array(
		'name' => __('تعداد تبلیغات متنی ستون چپ', 'options_check'),
		'desc' => __('تعداد تبلیغات متنی مورد نمایش در ستون چپ را وارد کنید. (عدد صفر قابل قبول نیست)', 'options_check'),
		'id' => 'reza-kianoosh-left-t-id1', //example_text
		'std' => '6',
		'type' => 'text');
$options[] = array(
		'name' => __('تعداد تبلیغات بنری ستون راست', 'options_check'),
		'desc' => __('تعداد تبلیغات بنری مورد نمایش در ستون راست را وارد کنید. (عدد صفر قابل قبول نیست)', 'options_check'),
		'id' => 'reza-kianoosh-right-id1', //example_text
		'std' => '2',
		'type' => 'text');
	return $options;
}